@@ -42,8 +42,8 @@ class TestToDictAndFromDict(unittest.TestCase):
         CatalogEntry(
             stream='users',
             tap_stream_id='prod_users',
-            database='prod',
-            table='users',
+            database_name='prod',
+            table_name='users',
             schema=Schema(
                 type='object',
                 selected=True,
@@ -53,8 +53,8 @@ class TestToDictAndFromDict(unittest.TestCase):
         CatalogEntry(
             stream='orders',
             tap_stream_id='prod_orders',
-            database='prod',
-            table='orders',
+            database_name='prod',
+            table_name='orders',
             schema=Schema(
                 type='object',
                 selected=True,
@@ -63,17 +63,17 @@ class TestToDictAndFromDict(unittest.TestCase):
                     'amount': Schema(type='number', selected=True)}))])
 
     def test_from_dict(self):
-        self.assertEqual(self.obj_form, Catalog.from_dict(self.dict_form))
+        self.assertEqual(self.obj_form.to_dict(), Catalog.from_dict(self.dict_form).to_dict())
 
     def test_to_dict(self):
         self.assertEqual(self.dict_form, self.obj_form.to_dict())
-        
+
 
 class TestGetStream(unittest.TestCase):
     def test(self):
         catalog = Catalog(
-            [CatalogEntry(tap_stream_id='a'),
-             CatalogEntry(tap_stream_id='b'),
-             CatalogEntry(tap_stream_id='c')])
+            [CatalogEntry(tap_stream_id='a', stream="a", schema={}),
+             CatalogEntry(tap_stream_id='b', stream="b", schema={}),
+             CatalogEntry(tap_stream_id='c', stream="c", schema={})])
         entry = catalog.get_stream('b')
         self.assertEquals('b', entry.tap_stream_id)
